@@ -1,11 +1,10 @@
 import aiohttp
-import json
 from .params import Params
 from .exceptions import EconetHTTPException, EconetUnauthorized, EconetUnknownId
 
 
 class Param(object):
-    def __init__(self, pid, data, enums):
+    def __init__(self, pid, data):
         self.desc = data.get("name", "")
         self.special = data.get("special", None)
         self.edit = data.get("edit", False)
@@ -16,13 +15,12 @@ class Param(object):
         self.maxv = data.get("maxv", None)
         self.offset = data.get("offset", None)
         self.mult = data.get("mult", None)
-        self.enums = enums
+        self.enum = None
 
     @property
     def value(self):
-        if self.special is not None and self.special != 0 and self._value is not None:
-            if len(self.enums[self.special]["values"]) > self._value:
-                return self.enums[self.special]["values"][self._value]
+        if self.enum is not None and self._value is not None:
+            return self.enum[self._value]
         return self._value
 
     @value.setter
@@ -44,18 +42,24 @@ class Econet(object):
         self.params = dict()
         self.units = dict()
         self.enums = dict()
-        self.save_requests = False
 
     def __repr__(self):
         return f"{self.__class__.__name__}(host={repr(self.host)}, login={repr(self.login)})"
 
     async def setup(self):
-        await self.fetch_units()
-        await self.fetch_enums()
-        await self.fetch_current_data_params()
-        await self.fetch_rm_params()
-        await self.fetch_reg_params_data()
-        await self.fetch_rm_params_data()
+        self.units = await self.fetch_units()
+        self.enums = await self.fetch_enums()
+        self.params = await self.fetch_current_data_params()
+        self.params.update(await self.fetch_rm_params())
+        await self.update()
+        for param in self.params.values():
+            if (
+                param.special is not None
+                and param.special != 0
+                and param.value is not None
+            ):
+                if len(self.enums[param.special]["values"]) > param.value:
+                    param.enum = self.enums[param.special]["values"]
 
     async def _call_api(self, cmd):
         async with aiohttp.ClientSession() as session:
@@ -69,23 +73,19 @@ class Econet(object):
                         f"{self.host}/econet/{cmd}"
                     )
                 j = await resp.json()
-                if self.save_requests is True:
-                    if not hasattr(self, "save_count"):
-                        self.save_count = 1
-                    with open(f"{self.save_count}_{cmd.split('?')[0]}.json") as fd:
-                        json.save(j, fd)
                 return j
 
     async def fetch_units(self):
         resp = await self._call_api("rmParamsUnitsNames")
-        self.units = resp["data"]
+        return resp["data"]
 
     async def fetch_enums(self):
         resp = await self._call_api("rmParamsEnums")
-        self.enums = resp["data"]
+        return resp["data"]
 
     async def fetch_current_data_params(self):
         resp = await self._call_api("rmCurrentDataParams")
+        params = dict()
         for pid, data in resp["data"].items():
             data["unit"] = (
                 self.units[int(data["unit"])]
@@ -95,10 +95,12 @@ class Econet(object):
             if pid == "123":
                 pid = "110"
             pid = Params.get_by_id(pid)
-            self.params[pid] = Param(pid, data, self.enums)
+            params[pid] = Param(pid, data)
+        return params
 
     async def fetch_rm_params(self):
         resp = await self._call_api("rmParamsData")
+        params = dict()
         for pid, data in enumerate(resp["data"]):
             data["unit"] = (
                 self.units[int(data["unit"])]
@@ -106,36 +108,53 @@ class Econet(object):
                 else ""
             )
             pid = Params.get_by_id(pid)
-            self.params[pid] = Param(pid, data, self.enums)
+            params[pid] = Param(pid, data)
+        return params
 
     async def fetch_sys_params(self):
         return await self._call_api("sysParams")
 
     async def fetch_reg_params_data(self):
         resp = await self._call_api("regParamsData")
+        params_data = dict()
         for pid, data in resp["data"].items():
             PID = Params.get_by_id(pid)
             if PID is not None:
-                if PID in self.params:
-                    self.params[PID].value = data
+                params_data[PID] = data
+        return params_data
 
     async def fetch_rm_params_data(self):
         resp = await self._call_api("rmParamsData")
+        params_data = dict()
         for pid, data in enumerate(resp["data"]):
             PID = Params.get_by_id(pid)
             if PID is not None:
-                self.params[PID].value = data["value"]
+                params_data[PID] = data
+        return params_data
 
     async def update(self):
-        await self.fetch_reg_params_data()
-        await self.fetch_rm_params_data()
+        params_data = await self.fetch_reg_params_data()
+        params_data.update(await self.fetch_rm_params_data())
+        for pid, data in params_data.items():
+            if pid not in self.params:
+                continue
+            if type(data) is dict:
+                self.params[pid].special = data.get("special", None)
+                self.params[pid].edit = data.get("edit", False)
+                self.params[pid].value = data.get("value", None)
+                self.params[pid].minv = data.get("minv", None)
+                self.params[pid].maxv = data.get("maxv", None)
+                self.params[pid].offset = data.get("offset", None)
+                self.params[pid].mult = data.get("mult", None)
+            else:
+                self.params[pid].value = data
 
     def get_param(self, param):
         if (p := self.params.get(param)) is None:
             if type(param) != Params and Params.get_by_id(param) is None:
                 raise EconetUnknownId(f"Unknow Parameter ID {param}.")
             undefined_data = dict(name=f"Undefined_{param}", unit="", value="Undefined")
-            p = Param(param, undefined_data, dict())
+            p = Param(param, undefined_data)
         return p
 
     async def set_param(self, param_id, value):
