@@ -230,33 +230,37 @@ class Smartfire(object):
                 (
                     1,
                     Params.TEMP_MIXER_1,
-                    Params.PRESET_TEMP_MIXER_1,
+                    Params.PRESET_MIXER_1,
                     Params.VALVE_MIXER_1,
                     Params.PUMP_MIXER_1,
+                    Params.MIXER_1_SUPPORT,
                 ),
                 (
                     2,
                     Params.TEMP_MIXER_2,
-                    Params.PRESET_TEMP_MIXER_2,
+                    Params.PRESET_MIXER_2,
                     Params.VALVE_MIXER_2,
                     Params.PUMP_MIXER_2,
+                    Params.MIXER_2_SUPPORT,
                 ),
                 (
                     3,
                     Params.TEMP_MIXER_3,
-                    Params.PRESET_TEMP_MIXER_3,
+                    Params.PRESET_MIXER_3,
                     Params.VALVE_MIXER_3,
                     Params.PUMP_MIXER_3,
+                    Params.MIXER_3_SUPPORT,
                 ),
                 (
                     4,
                     Params.TEMP_MIXER_4,
-                    Params.PRESET_TEMP_MIXER_4,
+                    Params.PRESET_MIXER_4,
                     Params.VALVE_MIXER_4,
                     Params.PUMP_MIXER_4,
+                    Params.MIXER_4_SUPPORT,
                 ),
             ]
-            for mid, param, preset, valve, pump in mixers_params:
+            for mid, param, preset, valve, pump, supported in mixers_params:
                 mixer = Mixer(self._econet, param, preset, valve, pump)
                 if mixer.temperature is not None:
                     mixers.append(mixer)
